package com.example.flutter_sklearn_plugin;

class SVC {

    private enum Kernel { LINEAR, POLY, RBF, SIGMOID }

    private int nClasses;
    private int nRows;
    private int[] classes;
    private double[][] vectors;
    private double[][] coefficients;
    private double[] intercepts;
    private int[] weights;
    private Kernel kernel;
    private double gamma;
    private double coef0;
    private double degree;

    public SVC(int nClasses, int nRows, double[][] vectors, double[][] coefficients, double[] intercepts, int[] weights, String kernel, double gamma, double coef0, double degree) {
        this.nClasses = nClasses;
        this.classes = new int[nClasses];
        for (int i = 0; i < nClasses; i++) {
            this.classes[i] = i;
        }
        this.nRows = nRows;

        this.vectors = vectors;
        this.coefficients = coefficients;
        this.intercepts = intercepts;
        this.weights = weights;

        this.kernel = Kernel.valueOf(kernel.toUpperCase());
        this.gamma = gamma;
        this.coef0 = coef0;
        this.degree = degree;
    }

    public int predict(double[] features) {

        double[] kernels = new double[vectors.length];
        double kernel;
        switch (this.kernel) {
            case LINEAR:
                // <x,x'>
                for (int i = 0; i < this.vectors.length; i++) {
                    kernel = 0.;
                    for (int j = 0; j < this.vectors[i].length; j++) {
                        kernel += this.vectors[i][j] * features[j];
                    }
                    kernels[i] = kernel;
                }
                break;
            case POLY:
                // (y<x,x'>+r)^d
                for (int i = 0; i < this.vectors.length; i++) {
                    kernel = 0.;
                    for (int j = 0; j < this.vectors[i].length; j++) {
                        kernel += this.vectors[i][j] * features[j];
                    }
                    kernels[i] = Math.pow((this.gamma * kernel) + this.coef0, this.degree);
                }
                break;
            case RBF:
                // exp(-y|x-x'|^2)
                for (int i = 0; i < this.vectors.length; i++) {
                    kernel = 0.;
                    for (int j = 0; j < this.vectors[i].length; j++) {
                        kernel += Math.pow(this.vectors[i][j] - features[j], 2);
                    }
                    kernels[i] = Math.exp(-this.gamma * kernel);
                }
                break;
            case SIGMOID:
                // tanh(y<x,x'>+r)
                for (int i = 0; i < this.vectors.length; i++) {
                    kernel = 0.;
                    for (int j = 0; j < this.vectors[i].length; j++) {
                        kernel += this.vectors[i][j] * features[j];
                    }
                    kernels[i] = Math.tanh((this.gamma * kernel) + this.coef0);
                }
                break;
        }

        int[] starts = new int[this.nRows];
        for (int i = 0; i < this.nRows; i++) {
            if (i != 0) {
                int start = 0;
                for (int j = 0; j < i; j++) {
                    start += this.weights[j];
                }
                starts[i] = start;
            } else {
                starts[0] = 0;
            }
        }

        int[] ends = new int[this.nRows];
        for (int i = 0; i < this.nRows; i++) {
            ends[i] = this.weights[i] + starts[i];
        }

        if (this.nClasses == 2) {

            for (int i = 0; i < kernels.length; i++) {
                kernels[i] = -kernels[i];
            }

            double decision = 0.;
            for (int k = starts[1]; k < ends[1]; k++) {
                decision += kernels[k] * this.coefficients[0][k];
            }
            for (int k = starts[0]; k < ends[0]; k++) {
                decision += kernels[k] * this.coefficients[0][k];
            }
            decision += this.intercepts[0];

            if (decision > 0) {
                return 0;
            }
            return 1;

        }

        double[] decisions = new double[this.intercepts.length];
        for (int i = 0, d = 0, l = this.nRows; i < l; i++) {
            for (int j = i + 1; j < l; j++) {
                double tmp = 0.;
                for (int k = starts[j]; k < ends[j]; k++) {
                    tmp += this.coefficients[i][k] * kernels[k];
                }
                for (int k = starts[i]; k < ends[i]; k++) {
                    tmp += this.coefficients[j - 1][k] * kernels[k];
                }
                decisions[d] = tmp + this.intercepts[d];
                d++;
            }
        }

        int[] votes = new int[this.intercepts.length];
        for (int i = 0, d = 0, l = this.nRows; i < l; i++) {
            for (int j = i + 1; j < l; j++) {
                votes[d] = decisions[d] > 0 ? i : j;
                d++;
            }
        }

        int[] amounts = new int[this.nClasses];
        for (int i = 0, l = votes.length; i < l; i++) {
            amounts[votes[i]] += 1;
        }

        int classVal = -1, classIdx = -1;
        for (int i = 0, l = amounts.length; i < l; i++) {
            if (amounts[i] > classVal) {
                classVal = amounts[i];
                classIdx= i;
            }
        }
        return this.classes[classIdx];

    }

//    public static void main(String[] args) {
//        if (args.length == 0) {
//
//            // Features:
////            double[] features = new double[args.length];
////            for (int i = 0, l = args.length; i < l; i++) {
////                features[i] = Double.parseDouble(args[i]);
////            }
//
//            double[] features = {-0.30887250000000005, -0.01823033333333331, 0.5271035 ,0.550573485429057 ,0.5799306455419188 ,0.900827707563383};
//
//            // Parameters:
//            double[][] vectors = {{-0.14819339999999998, 0.3184920000000001, 0.4462918, 0.3784382854340982, 1.9203603699635388, 0.779966067093114}, {-0.17192440000000003, 0.11548579999999994, 0.12150000000000002, 0.14756862114724797, 1.4319909827983206, 0.7265583752087647}, {-0.16305719999999999, 0.3969481999999999, 0.4117076, 0.4266084534092122, 1.0706829679399499, 0.7311607860896945}, {-0.2301032, 0.4919686, 0.11289800000000003, 0.07694175704518322, 1.176960113337236, 1.0841916590568754}, {-0.016621399999999998, 0.6481058, 0.08115479999999997, 0.19091193285072572, 0.6027066628565674, 1.1453139110517692}, {0.01210239999999999, 0.309579, 0.43697379999999997, 0.35228062874546484, 0.7593124525891828, 1.0156907653376592}, {-0.12325499999999998, 0.1487043999999999, 0.5961402, 0.2027545443572104, 1.7457288556177044, 1.0952921915101923}, {0.2208684, 0.41270439999999997, 1.014771, 0.4945928253622367, 0.9714336936419283, 0.8921022153792131}, {-0.1070444, 0.7802016, 0.2796332, 0.3252379143916035, 0.9972876233877067, 1.0757926391652808}, {-0.047116000000000005, 0.7109706, 0.2665832, 0.11759734757425441, 1.421110101349927, 0.43545228283843}, {-0.22287300000000002, 0.30581579999999997, 0.421066, 0.2829406863407948, 0.5895821668285092, 0.9695764627475236}, {-0.137762, -0.16152740000000004, 0.576026, 0.3284603365834298, 1.913585488230484, 0.8471697363093773}, {0.0403628, 0.4290804, 0.419074, 0.27291137715511243, 0.8793025593200556, 0.6709502545021502}, {-0.0908542, 0.201572, 0.040528600000000005, 0.22475355709910352, 0.4580697330057946, 0.1559578804030114}, {0.088287, 0.12487380000000003, 0.4706008, 0.17979164169810563, 1.6412705522322333, 0.7111376299600521}, {-0.0503258, 0.29235619999999995, 0.31464200000000003, 0.29257166509028176, 1.2841223648652804, 0.9611900759040847}, {0.080052, 0.4986198, 0.03208519999999998, 0.1333387824734424, 0.6089345610360771, 0.402661240480382}, {-0.3708182, 0.141646, 0.1247328, 0.4482594780941057, 0.18536242717983598, 0.3923210635483392}, {-0.06564620000000002, 0.0910274, 0.0800704, 0.41451018092406366, 0.1350294202083383, 0.3318757607935536}, {-0.4577395999999999, 0.275775, 0.33375140000000003, 0.9503231480845344, 1.1259169190211151, 0.4328822390296234}, {-0.41724179999999994, 0.0008449999999999847, 0.3563104, 0.8542071317301793, 0.7076393804710843, 0.586242188836491}, {-0.4090812, 0.3248436, 0.012102599999999996, 0.5997897995574782, 0.5113011716638247, 0.17941018339910364}, {-0.3542952, 0.2868564, 0.40888159999999996, 1.026917760938382, 1.0254761809019748, 0.9380817542977264}, {-0.6867672, 0.406515, 0.08235680000000001, 0.9194342447770258, 0.5337614174493132, 0.34469797011180675}, {-0.6743857999999999, 0.17515739999999996, 0.5403214000000001, 0.8632783693118344, 0.9115476987751655, 0.9197192104834496}, {-0.5368128000000001, 0.39815100000000003, 0.13439359999999995, 0.6958638606374095, 0.4974995975093849, 0.7412080672815832}, {-0.49328939999999993, 0.223649, 0.4610704, 0.6140129724666248, 0.4595056257027763, 0.9336525602130056}, {-0.7852134, 0.5568066, 0.3302276, 1.3446981190318517, 0.761597139880265, 0.8654798849772881}, {-0.4844018, 0.47413819999999995, 0.051496600000000003, 0.7915917361668829, 0.6923583851728814, 0.2812621880280035}, {-0.6155682, 0.2573302, 0.16004739999999998, 0.8170589525243573, 0.4760277955431804, 0.6784981702099866}, {-0.274795, 0.0108618, -0.031532399999999995, 0.3097268416847336, 0.047201600764169, 0.1272279656415994}, {-0.3250094, -0.0731066, 0.1752616, 0.744576582143704, 0.20461270272224058, 0.37219129536744944}, {-0.816324, 0.08627660000000001, 0.0777272, 1.1504728207865234, 0.25469629949667505, 0.15954437507069938}, {-0.5280926000000001, -0.0234558, -0.0014372000000000024, 0.8790506720945045, 0.08620302089660199, 0.0804043412864007}, {-0.47116939999999996, -0.05625100000000001, 0.027391600000000026, 0.7770169047844455, 0.2530503360568802, 0.597576476043276}, {-0.428246, -0.042401999999999995, 0.04338860000000001, 0.8056716266789465, 0.3870668128747283, 0.2969901377062882}, {-0.30761859999999996, -0.18946520000000003, 0.3460022, 0.9190158379518277, 0.33263679946181546, 0.4877597080050791}, {-0.5320853999999999, -0.010120600000000002, 0.03533139999999999, 0.7361462164035756, 0.1522965579758781, 0.3583139383994153}, {-0.15998900000000008, -0.092235, 0.2186248, 0.921483794106006, 0.3109935786941589, 0.4848965817694532}, {-0.317373, -0.2993466, 0.030779800000000003, 0.44040802262674555, 0.5851329990098832, 0.02336722565261011}, {-0.003953999999999969, -0.19815159999999998, -0.07632639999999999, 0.4920070539199616, 0.4222880022079718, 0.19647954365353154}, {-0.2090834, -0.26549659999999997, -0.0835804, 0.4962775867524142, 0.3420463068113731, 0.22394810384841396}, {-0.03900399999999997, -0.3356262, 0.11983060000000001, 0.6082743415367774, 0.559836068598389, 0.5221564752943317}, {-0.20514079999999998, -0.18650280000000002, -0.2273818, 0.3268014784195445, 0.41908644106580206, 0.3211560020008968}, {-0.06237280000000002, -0.3543196, -0.06397800000000001, 0.3664392664729041, 0.3689998483296436, 0.34152191808067023}, {-0.3710482, -0.2595136, -0.1112206, 0.48321700614651386, 0.4923824611918057, 0.17207160117608017}, {-0.49925700000000006, -0.3130112, -0.10751840000000001, 0.6571245603106766, 0.4591486090087826, 0.2552275357035365}, {0.045955199999999995, -0.1613416, -0.2522142, 0.5498282736534199, 0.22088918548856123, 0.627991882944119}, {0.08900619999999998, -0.24907939999999998, -0.04862919999999997, 0.8437478755162586, 0.6899866355345587, 1.3405785373247254}, {-0.060143199999999994, -0.3705892, 0.07205779999999999, 0.7993174719682412, 0.6193005226941117, 0.6613551025989745}, {-0.401419, -0.2267248, -0.161411, 0.6128424590622782, 0.7764795878944276, 0.46913013137881054}, {-0.24318599999999996, -0.3940314, -0.23171119999999998, 0.6841497377913698, 0.5089966224330963, 0.23465036919361537}, {0.30878659999999997, -0.0021377999999999454, 0.8661552, 0.5810048920274252, 1.1622425047156466, 0.6749851934199742}, {0.06947199999999998, 0.26420960000000004, 0.42118700000000003, 0.8316475276221291, 0.8541967882746926, 0.7518041556791901}, {0.3890668, 0.42956120000000003, 0.46043599999999996, 0.7125153436808923, 0.8724733367912741, 0.7338212372526431}, {0.05072540000000001, -0.0633712, 0.5745924, 0.9357769180722508, 1.0624659902404876, 0.6081870095445973}, {0.181829, 0.2887404, 0.044573800000000004, 0.25401367076793324, 0.4791899537493457, 0.19516333345098408}, {0.38683320000000004, 0.3457368, 0.153611, 0.5760961115284498, 0.49839943485993243, 0.2378814506271979}, {0.48562220000000006, 0.1842352, 0.47436860000000003, 0.6442803208287523, 0.39161351340473427, 0.6775721914064213}, {0.2918754, 0.3015188, 0.6294700000000001, 0.32166530705812835, 0.7372107855655666, 1.080210072455585}, {0.43923560000000006, 0.29217459999999995, 0.5278664, 0.6017140008133431, 0.32938908177761445, 0.5816892853433867}, {0.31106999999999996, 0.2960814, 0.33961040000000003, 0.328367755419895, 0.3521778429122139, 0.6152816607711464}, {0.457375, 0.23245259999999995, 0.7744481999999999, 0.7228001675020559, 0.7330737983077147, 0.9606590391170012}, {0.3995794, 0.30066699999999996, 0.499437, 0.3461135981210504, 0.7313228914545885, 0.46621441314967943}, {0.269012, 0.19945080000000004, 0.34229180000000003, 0.2475648811978387, 0.7296387871681439, 0.5022357399316579}, {0.4070792000000001, -0.113246, 0.415755, 1.0111346084442467, 0.2702020749809298, 0.4796724932993344}, {0.44608299999999995, -0.029677799999999997, 0.39495519999999995, 0.6443913041479532, 0.1229165763666561, 0.6132253789702445}, {0.354059, -0.1135512, 0.23596180000000003, 0.7322183867293282, 0.3794240683018145, 0.33010068129239}, {0.5117324, 0.1532662, 0.1073866, 0.8051775369170455, 0.2093572099085675, 0.25147728131045954}, {0.21719380000000005, -0.0348354, 0.313433, 0.9578160452470506, 0.17798883785451267, 0.34649359449490547}, {0.27736399999999994, 0.0068736000000000005, 0.161353, 0.5363044512098515, 0.058127223908423495, 0.3005390382387952}, {0.4678243999999999, -0.03469500000000001, 0.041699999999999994, 0.6354221284565874, 0.3928924809785751, 0.16037487228521805}, {0.4710202, 0.0197524, 0.0876084, 0.9123873851589576, 0.06893803625213007, 0.27049738116994776}, {0.3428708, -0.0437172, 0.401802, 0.6432428070982993, 0.052899331713170065, 0.6880694235242546}, {0.5664382, -0.012232799999999999, 0.11796419999999999, 0.677068671045781, 0.14574138905506562, 0.3849197830038098}, {0.3762852, -0.20186639999999997, -0.0889018, 0.42058571923235816, 0.3655143561473338, 0.34515412014229235}, {0.800202, -0.37782479999999996, 0.17570460000000004, 1.1027107262015727, 0.6026040731663702, 0.21320486425337487}, {0.22830320000000004, -0.24837479999999998, -0.0022402000000000047, 0.581488033622103, 0.44993348012589596, 0.1973245131900748}, {0.3534428, -0.22299200000000002, 0.06302940000000001, 0.5437726403072336, 0.49489223304725644, 0.513668295352458}, {0.224247, -0.25521340000000003, -0.044603199999999996, 0.7584890171825165, 0.4715306522717267, 0.16716193913298563}, {0.39238039999999996, -0.28967960000000004, 0.006468999999999997, 0.5631696499277993, 0.35220790162885335, 0.1309473076030966}, {0.4237438, -0.33331859999999996, 0.023764199999999996, 0.7651317005050176, 0.49941958625718713, 0.09530303209079971}, {0.2990056, -0.4330274, -0.002269599999999994, 0.42244901199588575, 0.5650608236418447, 0.2660466205974058}, {0.5533973999999999, -0.49543240000000005, -0.05678019999999999, 0.6570628149536389, 0.6631679810487686, 0.23706878473810084}, {0.7629968, -0.2406768, -0.080283, 1.0950552767192623, 0.8322499164744325, 0.45235974310718674}};
//            double[][] coefficients = {{0.4506689545426456, 0.5090825324810905, 0.5108879616886097, 0.46989617039457354, 0.5261516729374976, 0.0, 0.4126820809657665, 0.782609025321391, 0.39226493688595737, 0.6954834925063125, 0.9385764509763302, 0.5167252002237164, 0.08368649924177461, 1.0, 0.28967971568659934, 0.0, 0.5583866150673226, -0.5210404520145425, -1.0, -0.8491791083375663, -0.519685972703708, -0.8321109596952713, -0.6855648603091838, -0.587240978981832, -0.5393211561147283, -0.43792263237704265, -1.0, -1.0, -0.16471518838571284, -0.0, -1.0, -0.0, -1.0, -0.7821396485696684, -0.7743744624601699, -0.0, -0.6184325584777048, -0.0, -0.5433584958783011, -1.0, -0.737026417507924, -0.0, -0.022999721029756656, -0.5098824233339683, -0.08979354002161341, -0.0, -0.7315437565870708, -0.961691796493223, -1.0, -0.9544140062524801, -0.7341983912729645, -0.06003760441725812, -1.0, -0.7937532453223667, -0.5096350515190498, -0.8156208421139577, -1.0, -0.6735714447693861, -0.2276525193095412, -1.0, -0.38006168464123646, -0.5245039863772795, -0.8014175800022236, -0.11975123743170522, -1.0, -0.8520036109439846, -0.0, -0.0, -0.10747962072268798, -0.2265297259672944, -0.6556434230441366, -0.9947272717895698, -0.5051057718929972, -1.0, -0.0, -0.5626865223230184, -1.0, -0.0, -0.5481075181175922, -0.7068077201095438, -0.11006652674665457, -0.0, -0.35071533337968985, -0.6158111276247532, -1.0}, {0.32845298422618335, 0.3718241971832147, 0.20522945306007673, 0.3468957145659077, 0.406279695940528, 0.08323077340823978, 0.2982514430291683, 0.5673001678686704, 0.2920748300919827, 0.512581891093183, 0.37643818427509895, 0.37807685779345546, 0.15263608774864593, 0.8466898872893206, 0.21005140987041893, 0.034289283393080856, 0.3080023045486689, 1.0, 0.9396429801577363, 0.42199681818264834, 0.7637249722163687, 0.5911247475257732, 0.3683509051499215, 0.6139374275702053, 0.2498772872739892, 0.0, 0.4574448252496496, 0.6169549585439978, 0.0, 0.467738922385711, -1.0, -0.1867972464559174, -1.0, -0.5498404894229909, -0.9712652653886861, -0.3809988758811951, -0.6430088397066956, -0.25101426926619813, -0.5078688581343177, -1.0, -0.775777733883247, -0.0, -0.04451575659154861, -0.4341299211784991, -0.09994087870131584, -0.0, -0.7346376073813263, -0.9763380327575393, -1.0, -0.8669667928518144, -0.7064935097562569, -0.0, -0.7573978759261204, -0.7816367778261132, -0.2012369567454621, -0.799890643449164, -0.9436916030713859, -0.4889569180100502, -0.2597410547670046, -0.7234895902700786, -0.34006013316381767, -0.38379177156171185, -0.49526911790429845, -0.1690911645650988, -0.3273864713096509, -0.7733749356196343, -0.0, -0.0, -0.0745653243133305, -0.22501205965360896, -1.0, -0.8647669930814046, -0.3916852067672232, -0.8783404856272489, -0.0, -0.5647679627185979, -0.9032847606158969, -0.0, -0.4942380821985765, -0.6609345184648995, -0.08967679454536115, -0.0, -0.2893374477806258, -0.5385739251490202, -0.9446704145891011}, {0.3340955474844471, 0.3808702975169127, 0.21247684182351598, 0.3520030261009353, 0.41237101901962187, 0.09829428124329494, 0.3036230839752498, 0.57633742854759, 0.29558570214739555, 0.5207199636185655, 0.3736475535700558, 0.38418696965102433, 0.14946160293167907, 0.8258328057539657, 0.21315862835419608, 0.03265573489253274, 0.33626717028527636, 0.30255816266258495, 1.0, 0.5152502698941294, 0.5662723819755787, 0.5340302330409521, 0.4162372681091401, 0.40359265722434146, 0.334768428713795, 0.26705492341303333, 0.5019744195156973, 0.6903744194963884, 0.10668706905590634, 0.0, 1.0, 0.0, 0.7811763923130584, 0.4499804976450959, 0.6212870456777467, 0.9119417778875415, 0.3415632519908039, 0.0, 0.6366549966565088, 1.0, -0.5935743696337255, -0.37899450544100055, -0.14962089021566882, -0.08448189311228592, -0.0, -0.6797869295407348, -1.0, -0.7290423145921343, -0.8938449690275264, -0.7987736034314684, -0.43448448717621024, -0.0, -0.6301557211881919, -0.39947130392333535, -0.2525858955650403, -0.5965230823133515, -0.6464239465434527, -0.398481816113532, -0.23409934043581715, -0.5883674766874954, -0.2856999004442854, -0.23258724584404802, -0.40272618374759006, -0.1294143343988839, -0.30420696673125863, -0.5422052944412704, -0.0, -0.0, -0.0825535195764078, -0.6254904740412637, -0.5685680947308442, -0.7880392973381818, -0.277322912555324, -0.8005325647723607, -0.0, -0.41598070755472105, -0.7836090508359181, -0.0, -0.42963560619071317, -0.7031660454913513, -0.026211787037357936, -0.0, -0.33233123182562796, -0.43024714859441526, -0.819194517784972}, {0.4076089888804367, 0.47208296014445433, 0.14723519627860074, 0.4171061265958934, 0.4607263380088255, 1.0, 0.3748140865365847, 1.0, 0.279903048024307, 0.621106774270688, 0.10343728576602099, 0.47052070984352223, 0.7919378442028079, 1.0, 0.29948823293460464, 0.0, 1.0, 0.23477014759311202, 1.0, 0.700493501595562, 0.5748279908577271, 0.5565529472146727, 0.7325713906278501, 0.480333434309187, 0.37300860352361936, 0.33614722676293796, 0.6646243191174567, 0.8397492548298977, 0.17856126213793405, 0.0, 1.0, 0.0, 0.9199338197026106, 0.5879820795734948, 0.6104147755974705, 0.0, 0.4894987942599702, 0.0, 0.49291374480273625, 1.0, 0.6038781439432028, 0.0, 0.053067617985509956, 0.3138232389183526, 0.10127275129474338, 0.0, 0.6176477590660012, 0.8336753969801252, 1.0, 0.809302294152846, 0.6193853314108168, 0.070523722848518, -0.6088518945079148, -0.3917626509357543, -0.24355513934081802, -0.5966631217814122, -0.6659650002190409, -0.39822323250762065, -0.24237456558965925, -0.571040401223961, -0.2563349198648254, -0.23316828755715677, -0.3913999304114047, -0.10975899478189335, -0.3134781178786547, -0.6650493682537914, -0.0, -0.0, -0.0, -0.22675236749003802, -0.6466949854737049, -0.9392808599227614, -0.3934527012718415, -0.792584013195224, -0.0, -0.4805061436121543, -0.7861701788290172, -0.6945441461771786, -0.7238092722090257, -0.7214108947610398, -0.0, -0.0, -0.4757947220231572, -0.21215192626739784, -0.8208150257691944}, {0.25803827545178754, 0.2918534615942763, 0.1614255640959339, 0.2718690126049995, 0.3166484389607428, 0.07443692462305723, 0.23365141846410872, 0.4454764344023809, 0.22911663745410601, 0.401743662747923, 0.287955800427943, 0.29605224588201523, 0.11355668396784113, 0.46045025264655104, 0.16505259478750714, 0.02644241094717054, 0.30771960530232645, 0.0, 1.0, 0.41242137942792234, 0.2780926760742263, 0.31034601890188596, 0.32565468500573785, 0.3143244409943845, 0.27952501738257207, 0.22415551960936522, 0.40608276894946255, 0.5333350386971831, 0.12380746001971032, 0.0, 0.7087178517713743, 0.0, 0.6232816807659619, 0.3876097236127121, 0.31448685101069423, 0.0, 0.026362183056388388, 0.0, 0.9377141657200708, 0.6865397015184506, 0.7193663117832024, 0.0, 0.08663047018779282, 0.07224934483611761, 0.0, 0.0, 0.4263360477784852, 0.6719546637752238, 0.7609538698352872, 0.5122074527590175, 0.41411613465223485, 0.0, 0.4633821138330238, 0.276842809309086, 0.09641395688615761, 0.4283081814981831, 0.3937244046201005, 0.96470287986595, 1.0, 0.41563840001269525, 0.11925108291077788, 0.21841213584791908, 0.2074190215781474, 0.0, 0.17108130797497806, -0.8344707866984215, -0.5698859537682841, -0.0, -0.7262268356316025, -0.21946999879400308, -0.6141721019975289, -1.0, -0.0, -0.7909506174471789, -0.0, -0.5322564538793453, -0.8863344402910598, -0.0, -0.6360178881389279, -0.6193382901730304, -0.1142179029423068, -0.0, -0.2433730252796905, -0.5205918529951736, -0.9263741431857471}, {0.292070118593018, 0.33009613238839863, 0.18288788318863522, 0.3083427227806903, 0.35914309039186076, 0.08208844131110904, 0.2646331719671732, 0.504586038638108, 0.25886741053880374, 0.45431706299010577, 0.323377749921784, 0.3358714325054379, 0.1305293586120784, 0.5015220277970344, 0.186623132835282, 0.03022871090115359, 0.3490102629405792, 0.15784816480387004, 0.6989859436821306, 0.46937205181613756, 0.3116705023215595, 0.35409890519755866, 0.3709103039461773, 0.3546559579541063, 0.31897437126200595, 0.2452882642089182, 0.4578046197919497, 0.6058021053290301, 0.14007271574863486, 0.0, 0.7430942230846097, 0.0, 0.6864333186842282, 0.4384744843305307, 0.43967823737747663, 0.0, 0.28089611060752145, 0.0, 0.5076471110018758, 0.8441526102288344, 1.0, 0.0, 0.6747113288430983, 0.0, 0.3573076145003892, 0.0, 0.34948901953913436, 0.8016460105632632, 0.8455674224098664, 0.37759879416775227, 0.3976899802860314, 0.11119213933863012, 0.530995226647603, 0.3150272330005454, 0.21709688481598055, 0.5025091889805409, 0.5423109117410521, 0.4721178718475648, 0.35185608899666515, 0.48981053635702615, 0.11088328087848308, 0.22782149139735286, 0.32919481892888297, 0.039047833927394436, 0.34983262936619, 0.5589004050173704, 0.0, 1.0, 0.0, 0.0, 0.67884393995492, 1.0, 0.4332383019565141, 0.7383886724544012, 0.04238365314719704, -0.3124588211257057, -0.6595165856511714, -0.0, -1.0, -0.6410172442867765, -1.0, -0.17464705840178668, -0.0, -0.07378374041914426, -0.5903315226458181}};
//            double[] intercepts = {0.1830289165517983, 0.40381797407657044, 0.39426457089905054, 0.25299278141683806, 0.5324280646081856, 0.4704968021016552, 0.28988737002587334, 0.2219789750744668, 0.0401426207628734, 0.3976920274692228, 0.3158493441226432, -0.06705508404129742, -0.15248024419053613, 0.22533455776595984, 0.14025521470292068, -0.17795931022358047, 0.2122486939407179, 0.1309851827100654, 0.3952420199200586, 0.28924621180509336, -0.19074508811353058};
//            int[] weights = {17, 13, 10, 12, 13, 10, 10};
//
//            // Prediction:
//            SVC clf = new SVC(7, 7, vectors, coefficients, intercepts, weights, "rbf", 6, 0.0, 3);
//            int estimation = clf.predict(features);
//            System.out.println(estimation);
//
//        }
//    }
}
